<?php

declare(strict_types=1);

namespace Square\Models;

use Exception;
use Square\ApiHelper;
use stdClass;

/**
 * Indicates the source that generated the gift card
 * account number (GAN).
 */
class GiftCardGANSource
{
    /**
     * The GAN is generated by Square.
     */
    public const SQUARE = 'SQUARE';

    /**
     * The GAN is provided by a non-Square system. For more information, see
     * [Custom GANs](https://developer.squareup.com/docs/gift-cards/using-gift-cards-api#custom-gans) or
     * [Third-party gift cards](https://developer.squareup.com/docs/gift-cards/using-gift-cards-api#third-
     * party-gift-cards).
     */
    public const OTHER = 'OTHER';

    private const _ALL_VALUES = [self::SQUARE, self::OTHER];

    /**
     * Ensures that all the given values are present in this Enum.
     *
     * @param array|stdClass|null|string $value Value or a list/map of values to be checked
     *
     * @return array|null|string Input value(s), if all are a part of this Enum
     *
     * @throws Exception Throws exception if any given value is not in this Enum
     */
    public static function checkValue($value)
    {
        $value = json_decode(json_encode($value), true); // converts stdClass into array
        ApiHelper::checkValueInEnum($value, self::class, self::_ALL_VALUES);
        return $value;
    }
}
